# Columns

This section contains the existing steps intended to be used for common column operations to apply to the batches.

::: distilabel.steps.combine
::: distilabel.steps.expand
::: distilabel.steps.keep
